add here your [frame by frame animation](https://en.wikipedia.org/wiki/Stop_motion), every image in [png format](https://en.wikipedia.org/wiki/Portable_Network_Graphics).

the first frame need to be named 'frame-0', the second 'frame-1', and so on.

I have included an example (taken from [wikipedia](https://upload.wikimedia.org/wikipedia/commons/a/a4/Moving_Penny.gif) after resolution lowering).

#### DO NOT DELETE THIS FILE
